@@ -2,10 +2,11 @@ package MooX::LazierAttributes;
 
 use strict;
 use warnings;
+use Scalar::Util qw/reftype blessed/;
 
 use MooX::ReturnModifiers qw/return_modifiers/;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub import {
     my $target = caller;
@@ -27,11 +28,33 @@ sub construct_attribute {
     my $spec = shift;
     my %attr = ();
     $attr{is} = $spec->[0];
-    $attr{default} = sub { $spec->[1] } if defined $spec->[1];
+    $attr{default} = sub { _clone($spec->[1]) } if defined $spec->[1];
     map { $attr{$_} = $spec->[2]->{$_} } keys %{ $spec->[2] };
     return %attr;
 }
 
+sub _clone {
+    my ($to_clone) = @_;
+
+    my $blessed = blessed $to_clone;
+    my $clone    = _deep_clone($to_clone);
+    return $blessed ? bless $clone, $blessed : $clone;
+}
+
+sub _deep_clone {
+    my ($to_clone) = @_;
+    if ( reftype( \$to_clone ) eq 'SCALAR' ) {
+        return $to_clone;
+    }
+    elsif ( reftype($to_clone) eq 'HASH' ) {
+        return { map +( $_ => _clone( $to_clone->{$_} ) ), keys %$to_clone };
+    }
+    elsif ( reftype($to_clone) eq 'ARRAY' ) {
+        return [ map _clone($_), @$to_clone ];
+    }
+    return $to_clone;
+}
+
 1;
 
 __END__
@@ -43,7 +66,7 @@ MooX::LazierAttributes - Lazier Attributes.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
